%define pypi_name	virtualenv
# docs need sphinx >= 3
# docs need towncrier and that is not yet available when bootstrapping Python
%bcond_with docs

Name:		python-%{pypi_name}
Version:	20.29.2
Release:	%mkrel 1
Summary:	Virtual Python Environment builder
Group:		Development/Python
License:        MIT
URL:            https://pypi.org/project/virtualenv
Source0:        %{pypi_source}

# Add /usr/share/python-wheels to extra_search_dir
Patch1:         rpm-wheels.patch

BuildArch:	noarch
BuildRequires:	python3-devel

%if %{with docs}
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3dist(sphinx-rtd-theme)
BuildRequires:  python3dist(towncrier)
%endif

# RPM installed wheels
BuildRequires:	python-pip-wheel
BuildRequires:	python-setuptools-wheel
BuildRequires:	python-wheel-wheel

%description
virtualenv is a tool to create isolated Python environments.

%package -n	python3-%{pypi_name}
Summary:	Tool to create isolated Python 3 environments
Group:		Development/Python
Requires:	python3-devel
%{?python_provide:%python_provide python3-virtualenv}
Provides:	virtualenv = %{version}-%{release}

# RPM installed wheels
Requires:	python-pip-wheel
Requires:	python-setuptools-wheel
Requires:	python-wheel-wheel

%description -n python3-%{pypi_name}
virtualenv is a tool to create isolated Python 3 environments. virtualenv
is a successor to workingenv, and an extension of virtual-python. It is
written by Ian Bicking, and sponsored by the Open Planning Project. It is
licensed under an MIT-style permissive license

%if %{with docs}
%package -n     python-virtualenv-doc
Summary:    Documentation for python virtualenv
Group:		Development/Python

%description -n python-virtualenv-doc
Documentation for python virtualenv.
%endif

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Remove the wheels provided by RPM packages
rm src/virtualenv/seed/wheels/embed/pip-*
rm src/virtualenv/seed/wheels/embed/setuptools-*
rm src/virtualenv/seed/wheels/embed/wheel-*

test ! -f src/virtualenv/seed/embed/wheels/*.whl

# Replace hardcoded path from rpm-wheels.patch by %%{python_wheel_dir}
# On Fedora, this should change nothing, but when building for RHEL9+, it will
sed -i "s|/usr/share/python-wheels|%{python_wheel_dir}|" src/virtualenv/util/path/_system_wheels.py

# Allow platformdirs version 4
# Backported from release 20.24.7
# https://github.com/pypa/virtualenv/commit/55650340d9c9415bf035596266f245a8d59c6993
#sed -i "s/platformdirs<4/platformdirs<5/" pyproject.toml

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%if %{with docs}
PYTHONPATH=src %{python3} setup.py build_sphinx
rm -f build/sphinx/html/.buildinfo
%endif

%install
%pyproject_install
%pyproject_save_files virtualenv

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc LICENSE
%doc README.md
%{_bindir}/virtualenv

%if %{with docs}
%files -n python-virtualenv-doc
%doc build/sphinx/*
%endif


%changelog
* Sat Feb 22 2025 wally <wally> 20.29.2-1.mga10
+ Revision: 2150804
- new version 20.29.2
- rebuild for python3.13

* Tue Dec 19 2023 wally <wally> 20.25.0-1.mga10
+ Revision: 2019860
- new version 20.25.0
- new version 20.24.7

* Thu Dec 07 2023 wally <wally> 20.21.1-2.mga10
+ Revision: 2015162
- rebuild for py3.12

* Mon Nov 27 2023 wally <wally> 20.21.1-1.mga10
+ Revision: 2010165
- new version 20.21.1
- sync with Fedora where appropriate

* Wed Sep 07 2022 neoclust <neoclust> 20.15.1-1.mga9
+ Revision: 1885400
- New version 	20.15.1

* Tue Mar 29 2022 umeabot <umeabot> 20.13.0-4.mga9
+ Revision: 1831949
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 tv <tv> 20.13.0-3.mga9
+ Revision: 1773471
- Rebuild for python-3.10

* Fri Feb 04 2022 mrambo3501 <mrambo3501> 20.13.0-2.mga9
+ Revision: 1771512
- rebuild against python-filelock with fixed deps

* Fri Feb 04 2022 mrambo3501 <mrambo3501> 20.13.0-1.mga9
+ Revision: 1771459
- version 20.13.0
- rediff Patches 1 and 2

* Mon Mar 15 2021 neoclust <neoclust> 20.4.2-2.mga9
+ Revision: 1703222
- Rebuild against python 3.9

* Tue Mar 02 2021 guillomovitch <guillomovitch> 20.4.2-1.mga9
+ Revision: 1696337
- new version 20.4.2

* Tue Mar 31 2020 daviddavid <daviddavid> 16.7.10-1.mga8
+ Revision: 1562577
- new version: 16.7.10

* Thu Feb 20 2020 umeabot <umeabot> 16.7.9-2.mga8
+ Revision: 1546134
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 shlomif <shlomif> 16.7.9-1.mga8
+ Revision: 1486147
- New version 16.7.9

* Sat Sep 07 2019 wally <wally> 16.7.5-1.mga8
+ Revision: 1438178
- new version 16.7.5
- sync patches with Fedora
- drop python2 support
- rebuild for python3.8

* Mon Jan 07 2019 wally <wally> 16.1.0-3.mga7
+ Revision: 1350665
- rebuild for python3.7

* Tue Jan 01 2019 wally <wally> 16.1.0-2.mga7
+ Revision: 1348272
- require python-wheel-wheel
- require python-setuptools-wheel

* Tue Jan 01 2019 wally <wally> 16.1.0-1.mga7
+ Revision: 1348183
- new version 16.1.0
- add rediffed patches from Fedora
- default to python3

* Fri Sep 21 2018 umeabot <umeabot> 15.2.0-2.mga7
+ Revision: 1290457
- Mageia 7 Mass Rebuild

* Sun Apr 01 2018 kekepower <kekepower> 15.2.0-1.mga7
+ Revision: 1214056
- Update to version 15.2.0

* Thu Mar 22 2018 pterjan <pterjan> 15.1.0-3.mga7
+ Revision: 1211303
- Fix summary and obsoletes

* Mon Feb 26 2018 daviddavid <daviddavid> 15.1.0-2.mga7
+ Revision: 1205329
- fix requires

* Tue Feb 20 2018 kekepower <kekepower> 15.1.0-1.mga7
+ Revision: 1203714
- Added BR for python2-typing
- Update to version 15.1.0
- Rename python-virtualenv to python2-virtualenv

* Sat Aug 05 2017 pterjan <pterjan> 13.1.2-3.mga7
+ Revision: 1135681
- Rebuild for python 3.6

* Sat Feb 20 2016 umeabot <umeabot> 13.1.2-2.mga6
+ Revision: 972467
- Mageia 6 Mass Rebuild

* Sun Nov 08 2015 philippem <philippem> 13.1.2-1.mga6
+ Revision: 898708
- update to 13.1.2, add Python3

* Tue Apr 28 2015 philippem <philippem> 12.1.1-2.mga5
+ Revision: 820818
- update to 12.1.1 fix mga#15748

* Wed Oct 15 2014 umeabot <umeabot> 1.11.6-5.mga5
+ Revision: 745816
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.11.6-4.mga5
+ Revision: 729961
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.11.6-3.mga5
+ Revision: 688408
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 philippem <philippem> 1.11.6-2.mga5
+ Revision: 632670
- revert to Python 2.7 by default to not break firefox, thunderbird, iceape and wine-gecko builds

* Tue Jun 03 2014 philippem <philippem> 1.11.6-1.mga5
+ Revision: 632664
- update to 1.11.6, Python 3.4 by default
+ pterjan <pterjan>
- Rebuild for new Python

* Sun Dec 01 2013 philippem <philippem> 1.10.1-6.mga4
+ Revision: 554548
- change-match_hostname-to-follow-RFC-6125 (mga#11785)

* Tue Oct 22 2013 umeabot <umeabot> 1.10.1-5.mga4
+ Revision: 544426
- Mageia 4 Mass Rebuild

* Mon Oct 21 2013 philippem <philippem> 1.10.1-4.mga4
+ Revision: 539206
- fix inc_dir

* Tue Oct 15 2013 pterjan <pterjan> 1.10.1-3.mga4
+ Revision: 499706
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Sep 06 2013 philippem <philippem> 1.10.1-2.mga4
+ Revision: 475526
- bump release to have clean upgrade path from mga3 after the upgrade for security reason in mga2 and mga3

* Thu Aug 08 2013 philippem <philippem> 1.10.1-1.mga4
+ Revision: 464597
- Update to 1.10.1

* Mon Jul 29 2013 philippem <philippem> 1.10-1.mga4
+ Revision: 460644
- Update to 1.10

* Mon Jun 03 2013 kharec <kharec> 1.9.1-1.mga4
+ Revision: 436201
- New version 1.9.1
- Drop P0, it was applied upstream

* Sun Jan 13 2013 umeabot <umeabot> 1.7.1.2-4.mga3
+ Revision: 379674
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 23 2012 lebedov <lebedov> 1.7.1.2-3.mga3
+ Revision: 296929
- Remove python-devel install requirement (#4481).

* Fri Aug 03 2012 tv <tv> 1.7.1.2-2.mga3
+ Revision: 278204
- better upstream fix for multiarch (fix firefox15 build)

* Tue May 29 2012 lebedov <lebedov> 1.7.1.2-1.mga3
+ Revision: 249516
- Update to 1.7.1.2.
  Don't set PYTHONDONTWRITEBYTECODE (#3358).

* Wed Nov 30 2011 lebedov <lebedov> 1.7-1.mga2
+ Revision: 174425
- Update to 1.7.

* Mon Sep 26 2011 lebedov <lebedov> 1.6.4-2.mga2
+ Revision: 148995
- imported package python-virtualenv

